@@ -363,6 +363,7 @@ define!({
         Document(DocumentRule),
         ColorProfile(ColorProfileRule),
         CounterStyle(CounterStyleRule),
+        Property(PropertyRule),
         Unknown(UnknownAtRule),
     }
 
@@ -683,4 +684,10 @@ define!({
         pub name: CustomIdent,
         pub block: Vec<DeclarationBlockItem>,
     }
+
+    pub struct PropertyRule {
+        pub span: Span,
+        pub name: DashedIdent,
+        pub block: Vec<DeclarationBlockItem>,
+    }
 });
